@@ -28,7 +28,7 @@ try:
 except ImportError:
     from urllib import unquote
 
-__version__ = "0.3.9"
+__version__ = "0.3.10"
 
 _this_year = date.today().year % 100
 _this_cent = date.today().year // 100
@@ -193,8 +193,10 @@ def authoryear2bibcode(author, year, key):
             )
         )
         print(
-            _headerize("Choose one entry from above for <{}>".format(key)),
-            extraline=False,
+            _headerize(
+                "Choose one entry from above for <{}>".format(key),
+                extraline=False,
+            )
         )
         choices = list(range(0, len(entries) + 1))
         c = -1
